AllocError

Enum AllocError 

pub enum AllocError {
    InvalidParam,
    AlreadyInitialized,
    MemoryOverlap,
    NoMemory,
    NotAllocated,
    NotInitialized,
    NotFound,
}
The error type used for allocation operations.

Variants



InvalidParam

Invalid size, alignment, or other input parameter.



AlreadyInitialized

A global allocator instance has already been initialized.



MemoryOverlap

A region overlaps with an existing managed region.



NoMemory

Not enough memory is available to satisfy the request.



NotAllocated

Attempted to deallocate memory that was not allocated.



NotInitialized

The allocator has not been initialized.



NotFound

The requested address or entity was not found in any managed region.